@@ -644,22 +644,29 @@ void Log::log(MsgType mt, const QString &console, const QString &terse, bool own
 	if ((flags & Settings::LogConsole)) {
 		QTextCursor tc = Global::get().mw->qteLog->textCursor();
 
+		tc.movePosition(QTextCursor::End);
+
+		// A newline is inserted after each frame, but this spaces out the
+		// log entries too much, so the font size is set to near-zero in order
+		// to reduce the space between log entries. This font size is set only
+		// for the blank lines between entries, not for entries themselves.
+		QTextCharFormat cf = tc.blockCharFormat();
+		cf.setFontPointSize(0.01);
+		tc.setBlockCharFormat(cf);
+
 		// We copy the value from the settings in order to make sure that
 		// we use the same margin everywhere while in this method (even if
 		// the setting might change in that time).
 		const int msgMargin = Global::get().s.iChatMessageMargins;
 
-		QTextBlockFormat format = tc.blockFormat();
-		format.setTopMargin(msgMargin);
-		format.setBottomMargin(msgMargin);
-		tc.setBlockFormat(format);
+		QTextFrameFormat qttf;
+		qttf.setTopMargin(0);
+		qttf.setBottomMargin(msgMargin);
 
 		LogTextBrowser *tlog     = Global::get().mw->qteLog;
 		const int oldscrollvalue = tlog->getLogScroll();
 		const bool scroll        = (oldscrollvalue == tlog->getLogScrollMaximum());
 
-		tc.movePosition(QTextCursor::End);
-
 		if (qdDate != dt.date()) {
 			qdDate = dt.date();
 			tc.insertBlock();
@@ -677,19 +684,13 @@ void Log::log(MsgType mt, const QString &console, const QString &terse, bool own
 			// paint a border around the message to make clear that it contains invisible parts.
 			// The beginning of the message is clear anyway (the date and potentially the "To XY" part)
 			// so we don't have to care about that.
-			QTextFrameFormat qttf;
 			qttf.setBorder(1);
 			qttf.setPadding(2);
-			qttf.setMargin(msgMargin);
 			qttf.setBorderStyle(QTextFrameFormat::BorderStyle_Dashed);
-			tc.insertFrame(qttf);
-		} else if (!tc.block().text().isEmpty()) {
-			// Only insert a block if the current block is not empty. It may be empty because
-			// it is the default block of an empty document. Another cause might be that apparently
-			// a new empty block is automatically inserted after a frame.
-			tc.insertBlock();
 		}
 
+		tc.insertFrame(qttf);
+
 		const QString timeString =
 			dt.time().toString(QLatin1String(Global::get().s.bLog24HourClock ? "HH:mm:ss" : "hh:mm:ss AP"));
 		tc.insertHtml(Log::msgColor(QString::fromLatin1("[%1] ").arg(timeString.toHtmlEscaped()), Log::Time));
@@ -698,6 +699,9 @@ void Log::log(MsgType mt, const QString &console, const QString &terse, bool own
 		tc.movePosition(QTextCursor::End);
 		Global::get().mw->qteLog->setTextCursor(tc);
 
+		// Shrink trailing blank line after the most recent log entry.
+		tc.setBlockCharFormat(cf);
+
 		if (scroll || ownMessage)
 			tlog->scrollLogToBottom();
 		else
@@ -713,7 +717,8 @@ void Log::log(MsgType mt, const QString &console, const QString &terse, bool own
 
 			// Message notification with balloon tooltips
 			if (flags & Settings::LogBalloon) {
-				postNotification(mt, plain);
+				// Replace any instances of a "Object Replacement Character" from QTextDocumentFragment::toPlainText
+				postNotification(mt, plain.replace("\xEF\xBF\xBC", tr("[embedded content]")));
 			}
 		}
 
