@@ -326,14 +326,10 @@ Settings::Settings() {
 	iVoiceHold                     = 50;
 	iJitterBufferSize              = 1;
 	iFramesPerPacket               = 2;
-#ifdef USE_RNNOISE
-	noiseCancelMode = NoiseCancelRNN;
-#else
-	noiseCancelMode = NoiseCancelSpeex;
-#endif
-	iSpeexNoiseCancelStrength = -30;
-	bAllowLowDelay            = true;
-	uiAudioInputChannelMask   = 0xffffffffffffffffULL;
+	noiseCancelMode                = NoiseCancelSpeex;
+	iSpeexNoiseCancelStrength      = -30;
+	bAllowLowDelay                 = true;
+	uiAudioInputChannelMask        = 0xffffffffffffffffULL;
 
 	// Idle auto actions
 	iIdleTime                   = 5 * 60;
@@ -534,6 +530,7 @@ Settings::Settings() {
 
 #ifdef Q_OS_LINUX
 	if (EnvUtils::waylandIsUsed()) {
+		// Due to the issues we're currently having on Wayland, we disable shortcuts by default
 		bShortcutEnable = false;
 	}
 #endif
@@ -1011,13 +1008,6 @@ void Settings::load(QSettings *settings_ptr) {
 	LOAD(bEnableXboxInput, "shortcut/windows/xbox/enable");
 	LOAD(bEnableUIAccess, "shortcut/windows/uiaccess/enable");
 
-#ifdef Q_OS_LINUX
-	if (EnvUtils::waylandIsUsed()) {
-		// Global shortcuts don't work on Wayland
-		bShortcutEnable = false;
-	}
-#endif
-
 	// Search options
 	LOAD(searchForUsers, "search/search_for_users");
 	LOAD(searchForChannels, "search/search_for_channels");
