@@ -157,6 +157,10 @@ int main(int argc, char **argv) {
 	a.setOrganizationDomain(QLatin1String("mumble.sourceforge.net"));
 	a.setQuitOnLastWindowClosed(false);
 
+#if QT_VERSION >= 0x050700
+	a.setDesktopFileName("info.mumble.Mumble");
+#endif
+
 #if QT_VERSION >= 0x050100
 	a.setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
